<?php
class UserFiles {

   var $_kernel;

   function UserFiles () {
     global $xcKernel;
     include("UserFiles.methodTable.php");
     $this->_kernel = $xcKernel;
   }

   /**
   * Get current user file list
   * @access remote
   */
   function getFileList() {
      $kernel = $this->_kernel;
      $servOnto = $kernel->srvFactory("AdvOntology");
      $servUserFiles = $kernel->srvFactory("XmUserFiles");
      if ($servOnto) {
        if($kernel->GetUser()) {
          $res = array();
          $userOntoId = $servOnto->utilGetCurUserField("id");
          $fileIds = $servUserFiles->getUserFilesId($userOntoId, $_SESSION["xmUserFileFolderId"]);
          $fileList = $servOnto->getConceptsByIds("UserFile", $fileIds);

          $res["filelist"] = $fileList;
          $res["usedQuota"] = $servUserFiles->getUserUsedQuota($userOntoId);
          $res["quota"] = $servUserFiles->getUserQuota($userOntoId);
          $res["maxfilesize"] = $kernel->config["upload_max_size"];

          return $kernel->amfResultOk($res);
        } else {
          return $kernel->amfResultError("Only users can have files");
        }
      } else {
        return $kernel->amfResultError("Service AdvOntology isn't installed");
      }
   }

   /**
   * Get current user folder list
   * @access remote
   */
   function getFolderList() {
      $kernel = $this->_kernel;
      $servOnto = $kernel->srvFactory("AdvOntology");
      $servUserFiles = $kernel->srvFactory("XmUserFiles");
      if ($servOnto) {
        if($kernel->GetUser()) {
          $res = array();
          $userOntoId = $servOnto->utilGetCurUserField("id");
          /*
          $fileIds = $servUserFiles->getUserFilesId($userOntoId);
          $fileList = $servOnto->getConceptsByIds("UserFile", $fileIds);

          $res["filelist"] = $fileList;
          $res["usedQuota"] = $servUserFiles->getUserUsedQuota($userOntoId);
          $res["quota"] = $servUserFiles->getUserQuota($userOntoId);
          $res["maxfilesize"] = $kernel->config["upload_max_size"];
          */
          $res = $servOnto->getLinksAndData("UserFolders",  array("User1" => $userOntoId), "UserFolder1");
          return $kernel->amfResultOk($res);
        } else {
          return $kernel->amfResultError("Only users can have files");
        }
      } else {
        return $kernel->amfResultError("Service AdvOntology isn't installed");
      }
   }

   /**
   * Remove some user file. Right access check.
   * @param $fileid file id
   * @access remote
   */
   function delFile($fileid) {
      $kernel = $this->_kernel;
      $servOnto = $kernel->srvFactory("AdvOntology");
      $servUserFiles = $kernel->srvFactory("XmUserFiles");
      if ($servOnto) {
        if($kernel->GetUser()) {
          if($servUserFiles->isCurUserFileOwner($fileid)) {
             $servUserFiles->delUserFile($fileid);
             return $kernel->amfResultOk("ok");
          } else {
             return $kernel->amfResultError("         ");
          }

        } else {
          return $kernel->amfResultError("Only users can have files");
        }
      } else {
        return $kernel->amfResultError("Service AdvOntology isn't installed");
      }
   }

   /**
   * Get last errors during file upload
   * @access remote
   */
   function getFileUploadErrors() {
     $kernel = $this->_kernel;
     return $kernel->amfResultOk($_SESSION["fileuperrors"]);
   }

   /**
   * Add remote file by url
   * @param $url file url
   * @access remote
   */
   function addFileByUrl($url) {
     $kernel = $this->_kernel;
      $servOnto = $kernel->srvFactory("AdvOntology");
      $servUserFiles = $kernel->srvFactory("XmUserFiles");
      if ($servOnto) {
        if($kernel->GetUser()) {
          $userOntoId = $servOnto->utilGetCurUserField("id");
          $res = $servUserFiles->addFileByURL($userOntoId,$url);
          if($res) {
             return $kernel->amfResultOk("ok");
          } else {
             return $kernel->amfResultError("     .");
          }
        } else {
          return $kernel->amfResultError("Only users can have files");
        }
      } else {
        return $kernel->amfResultError("Service AdvOntology isn't installed");
      }
   }

   /**
   * Add folder
   * @param $name folder name
   * @access remote
   */
   function addFolder($name) {
     $kernel = $this->_kernel;
      $servOnto = $kernel->srvFactory("AdvOntology");
      $servUserFiles = $kernel->srvFactory("XmUserFiles");
      if ($servOnto) {
        if($kernel->GetUser()) {
          $userOntoId = $servOnto->utilGetCurUserField("id");
          //$res = $servUserFiles->addFileByURL($userOntoId,$url);
          $foldid = $servOnto->addConcept("UserFolder", $name);
          $servOnto->addLink("UserFolders", array("User1" => $userOntoId, "UserFolder1" => $foldid));
          return $kernel->amfResultOk("");
        } else {
          return $kernel->amfResultError("Only users can have files");
        }
      } else {
        return $kernel->amfResultError("Service AdvOntology isn't installed");
      }
   }

   /**
   * Set folder
   * @access remote
   */
   function setFolder($folderId) {
      $kernel = $this->_kernel;
      $_SESSION["xmUserFileFolderId"] = (int)$folderId;
      return $kernel->amfResultOk("");
   }

   /**
   * Save jpeg file, coded as BASE64 in current folder
   * @access remote
   */
   function saveJPEG($filename, $data) {
      $kernel = $this->_kernel;
      $servOnto = $kernel->srvFactory("AdvOntology");
      $servUserFiles = $kernel->srvFactory("XmUserFiles");
      if ($servOnto) {
        if($kernel->GetUser()) {
          $userOntoId = $servOnto->utilGetCurUserField("id");

          $dir = $servUserFiles->getUserDir($userOntoId)."/";
          $filename = $servUserFiles->getCorrectFileName($userOntoId, $filename.'.jpg');

          file_put_contents($dir.$filename, base64_decode($data));
          $file_size = filesize($dir.$filename);


          $fileontoid = $servOnto->addConcept("UserFile",
                          $servUserFiles->getUserFileURL($userOntoId, $filename), null,
                          array("local" => 1, "filename" => $filename, "filesize" => $file_size, "filetype" => "image")
                          );
          $servOnto->addLink("UserFileOwner", array("UserFile1" => $fileontoid, "UserFolder1" => $_SESSION["xmUserFileFolderId"], "User1" => $userOntoId));

          return $kernel->amfResultOk($filename);

        } else {
          return $kernel->amfResultError("Only users can have files");
        }
      } else {
        return $kernel->amfResultError("Service AdvOntology isn't installed");
      }
   }

   /**
   * Load file by url, and save it into some file
   * @access remote
   */
   function addFileByURLDownload($url, $filename) {
      $kernel = $this->_kernel;
      $servOnto = $kernel->srvFactory("AdvOntology");
      $servUserFiles = $kernel->srvFactory("XmUserFiles");
      if ($servOnto) {
        if($kernel->GetUser()) {
          $userOntoId = $servOnto->utilGetCurUserField("id");

          $dir = $servUserFiles->getUserDir($userOntoId)."/";
          $filename = $servUserFiles->getCorrectFileName($userOntoId, $filename);

          $_data = explode(".", $filename );
          $ext  = strtolower($_data[ sizeof($_data)-1 ]);
          $isimage = ($ext=='jpg') || ($ext=='png') || ($ext=='gif') || ($ext=='bmp');

          file_put_contents($dir.$filename, file_get_contents($url));
          $file_size = filesize($dir.$filename);


          $fileontoid = $servOnto->addConcept("UserFile",
                          $servUserFiles->getUserFileURL($userOntoId, $filename), null,
                          array("local" => 1, "filename" => $filename, "filesize" => $file_size, "filetype" => (!$isimage?"file":"image"))
                          );
          $servOnto->addLink("UserFileOwner", array("UserFile1" => $fileontoid, "UserFolder1" => $_SESSION["xmUserFileFolderId"], "User1" => $userOntoId));

          $filedata = $servOnto->getConcept("UserFile", $fileontoid);

          return $kernel->amfResultOk($filedata);

        } else {
          return $kernel->amfResultError("Only users can have files");
        }
      } else {
        return $kernel->amfResultError("Service AdvOntology isn't installed");
      }
   }

}

?>
